========================
Django Frontend Template
========================

Django Frontend Template is a very basic Django template built on `HTML5 Boilerplate <https://github.com/h5bp/html5-boilerplate>`_.

With the convenience of a light-weight installable Django application, create custom templates built on top of one of the most well-known, widespread templates (HTML5 Boilerplate.)

There are no static files included. If you want a heavier-weight application built on HTML5 Boilerplate and Twitter Bootstrap then checkout `django-frontend-skeleton <https://github.com/jonfaustman/django-frontend-skeleton>`_. If you want to include often used static files then without any templates check out `django-frontend-static <https://github.com/jonfaustman/django-frontend-static>`_.

-------------
Inactive
-------------

Django Frontend Template is now inactive. Please use `django-frontend <https://github.com/jonfaustman/django-frontend>`_.

While continuing to use Django Frontend Template, be sure to force upgrade to avoid namespacing problems.

`Read this article <http://jonfaustman.com/2013/08/07/django-frontend/>`_ for more information.

---------
Starring
---------
* `HTML5 Boilerplate (based on 4.2.0) <https://github.com/h5bp/html5-boilerplate>`_

-----------------
More Information
-----------------

For more information, instructions on how to get started, a changelog and a roadmap `read the documentation <https://django-frontend-skeleton.readthedocs.org/>`_.